.htaccess
CONTRIBUTING.md
ChangeLog
LICENSE
app
assets
cli
config.default.php
data
docker-compose.mysql.yml
docker-compose.postgres.yml
docker-compose.sqlite.yml
favicon.ico
healthcheck.php
index.php
jsonrpc.php
libs
plugins
robots.txt
vendor
web.config
config.php